abacusai.feature_group_row — AbacusAI documentation

# abacusai.feature_group_row

## Classes

`FeatureGroupRow` | A row of a feature group.

## Module Contents

class abacusai.feature_group_row.FeatureGroupRow(client, featureGroupId=None, primaryKey=None, createdAt=None, updatedAt=None, contents=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A row of a feature group.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupId (str) – The ID of the feature group this row belongs to.

    - primaryKey (str) – Value of the primary key for this row.

    - createdAt (str) – The timestamp this feature group row was created in ISO-8601 format.

    - updatedAt (str) – The timestamp when this feature group row was last updated in ISO-8601 format.

    - contents (dict) – A dictionary of feature names and values for this row.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict